==> vala-0.1.5.tar.bz2: vala-0.1.5/ccode/valaccodeenumvalue.c <==
/* valaccodeenumvalue.vala
 *
 * Copyright (C) 2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <ccode/valaccodeenumvalue.h>

struct _ValaCCodeEnumValuePrivate {
	char* _name;
	ValaCCodeExpression* _value;
};
#define VALA_CCODE_ENUM_VALUE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_ENUM_VALUE, ValaCCodeEnumValuePrivate))
enum  {
	VALA_CCODE_ENUM_VALUE_DUMMY_PROPERTY,
	VALA_CCODE_ENUM_VALUE_NAME,
	VALA_CCODE_ENUM_VALUE_VALUE
};
static void vala_ccode_enum_value_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_enum_value_parent_class = NULL;
static void vala_ccode_enum_value_dispose (GObject * obj);


ValaCCodeEnumValue* vala_ccode_enum_value_new (const char* name, ValaCCodeExpression* value) {
	ValaCCodeEnumValue * self;
	g_return_val_if_fail (name != NULL, NULL);
	g_return_val_if_fail (value == NULL || VALA_IS_CCODE_EXPRESSION (value), NULL);
	self = g_object_newv (VALA_TYPE_CCODE_ENUM_VALUE, 0, NULL);
	vala_ccode_enum_value_set_name (self, name);
	vala_ccode_enum_value_set_value (self, value);
	return self;
}


static void vala_ccode_enum_value_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
	ValaCCodeEnumValue * self;
	self = VALA_CCODE_ENUM_VALUE (base);
	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
	vala_ccode_writer_write_string (writer, vala_ccode_enum_value_get_name (self));
	if (vala_ccode_enum_value_get_value (self) != NULL) {
		vala_ccode_writer_write_string (writer, " = ");
		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_enum_value_get_value (self)), writer);
	}
}


char* vala_ccode_enum_value_get_name (ValaCCodeEnumValue* self) {
	g_return_val_if_fail (VALA_IS_CCODE_ENUM_VALUE (self), NULL);
	return self->priv->_name;
}


void vala_ccode_enum_value_set_name (ValaCCodeEnumValue* self, const char* value) {
	char* _tmp1;
	g_return_if_fail (VALA_IS_CCODE_ENUM_VALUE (self));
	_tmp1 = NULL;
	self->priv->_name = (_tmp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp1);
}


ValaCCodeExpression* vala_ccode_enum_value_get_value (ValaCCodeEnumValue* self) {
	g_return_val_if_fail (VALA_IS_CCODE_ENUM_VALUE (self), NULL);
	return self->priv->_value;
}


void vala_ccode_enum_value_set_value (ValaCCodeEnumValue* self, ValaCCodeExpression* value) {
	ValaCCodeExpression* _tmp2;
	ValaCCodeExpression* _tmp1;
	g_return_if_fail (VALA_IS_CCODE_ENUM_VALUE (self));
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_value == NULL ? NULL : (self->priv->_value = (g_object_unref (self->priv->_value), NULL))), _tmp2);
}


static void vala_ccode_enum_value_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValaCCodeEnumValue * self;
	self = VALA_CCODE_ENUM_VALUE (object);
	switch (property_id) {
		case VALA_CCODE_ENUM_VALUE_NAME:
		g_value_set_string (value, vala_ccode_enum_value_get_name (self));
		break;
		case VALA_CCODE_ENUM_VALUE_VALUE:
		g_value_set_object (value, vala_ccode_enum_value_get_value (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_ccode_enum_value_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValaCCodeEnumValue * self;
	self = VALA_CCODE_ENUM_VALUE (object);
	switch (property_id) {
		case VALA_CCODE_ENUM_VALUE_NAME:
		vala_ccode_enum_value_set_name (self, g_value_get_string (value));
		break;
		case VALA_CCODE_ENUM_VALUE_VALUE:
		vala_ccode_enum_value_set_value (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_ccode_enum_value_class_init (ValaCCodeEnumValueClass * klass) {
	vala_ccode_enum_value_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaCCodeEnumValuePrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_ccode_enum_value_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_ccode_enum_value_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_ccode_enum_value_dispose;
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_enum_value_real_write;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ENUM_VALUE_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ENUM_VALUE_VALUE, g_param_spec_object ("value", "value", "value", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void vala_ccode_enum_value_init (ValaCCodeEnumValue * self) {
	self->priv = VALA_CCODE_ENUM_VALUE_GET_PRIVATE (self);
}


static void vala_ccode_enum_value_dispose (GObject * obj) {
	ValaCCodeEnumValue * self;
	self = VALA_CCODE_ENUM_VALUE (obj);
	(self->priv->_name = (g_free (self->priv->_name), NULL));
	(self->priv->_value == NULL ? NULL : (self->priv->_value = (g_object_unref (self->priv->_value), NULL)));
	G_OBJECT_CLASS (vala_ccode_enum_value_parent_class)->dispose (obj);
}


GType vala_ccode_enum_value_get_type (void) {
	static GType vala_ccode_enum_value_type_id = 0;
	if (G_UNLIKELY (vala_ccode_enum_value_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeEnumValueClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_enum_value_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeEnumValue), 0, (GInstanceInitFunc) vala_ccode_enum_value_init };
		vala_ccode_enum_value_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeEnumValue", &g_define_type_info, 0);
	}
	return vala_ccode_enum_value_type_id;
}

==> vala-0.1.7.tar.bz2: vala-0.1.7/ccode/valaccodeenumvalue.c <==
/* valaccodeenumvalue.vala
 *
 * Copyright (C) 2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <ccode/valaccodeenumvalue.h>

struct _ValaCCodeEnumValuePrivate {
	char* _name;
	ValaCCodeExpression* _value;
};
#define VALA_CCODE_ENUM_VALUE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_ENUM_VALUE, ValaCCodeEnumValuePrivate))
enum  {
	VALA_CCODE_ENUM_VALUE_DUMMY_PROPERTY,
	VALA_CCODE_ENUM_VALUE_NAME,
	VALA_CCODE_ENUM_VALUE_VALUE
};
static void vala_ccode_enum_value_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_enum_value_parent_class = NULL;
static void vala_ccode_enum_value_dispose (GObject * obj);


ValaCCodeEnumValue* vala_ccode_enum_value_new (const char* name, ValaCCodeExpression* value) {
	ValaCCodeEnumValue * self;
	g_return_val_if_fail (value == NULL || VALA_IS_CCODE_EXPRESSION (value), NULL);
	self = g_object_newv (VALA_TYPE_CCODE_ENUM_VALUE, 0, NULL);
	vala_ccode_enum_value_set_name (self, name);
	vala_ccode_enum_value_set_value (self, value);
	return self;
}


static void vala_ccode_enum_value_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
	ValaCCodeEnumValue * self;
	self = VALA_CCODE_ENUM_VALUE (base);
	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
	vala_ccode_writer_write_string (writer, vala_ccode_enum_value_get_name (self));
	if (vala_ccode_enum_value_get_value (self) != NULL) {
		vala_ccode_writer_write_string (writer, " = ");
		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_enum_value_get_value (self)), writer);
	}
}


char* vala_ccode_enum_value_get_name (ValaCCodeEnumValue* self) {
	g_return_val_if_fail (VALA_IS_CCODE_ENUM_VALUE (self), NULL);
	return self->priv->_name;
}


void vala_ccode_enum_value_set_name (ValaCCodeEnumValue* self, const char* value) {
	char* _tmp2;
	const char* _tmp1;
	g_return_if_fail (VALA_IS_CCODE_ENUM_VALUE (self));
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
}


ValaCCodeExpression* vala_ccode_enum_value_get_value (ValaCCodeEnumValue* self) {
	g_return_val_if_fail (VALA_IS_CCODE_ENUM_VALUE (self), NULL);
	return self->priv->_value;
}


void vala_ccode_enum_value_set_value (ValaCCodeEnumValue* self, ValaCCodeExpression* value) {
	ValaCCodeExpression* _tmp2;
	ValaCCodeExpression* _tmp1;
	g_return_if_fail (VALA_IS_CCODE_ENUM_VALUE (self));
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_value == NULL ? NULL : (self->priv->_value = (g_object_unref (self->priv->_value), NULL))), _tmp2);
}


static void vala_ccode_enum_value_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValaCCodeEnumValue * self;
	self = VALA_CCODE_ENUM_VALUE (object);
	switch (property_id) {
		case VALA_CCODE_ENUM_VALUE_NAME:
		g_value_set_string (value, vala_ccode_enum_value_get_name (self));
		break;
		case VALA_CCODE_ENUM_VALUE_VALUE:
		g_value_set_object (value, vala_ccode_enum_value_get_value (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_ccode_enum_value_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValaCCodeEnumValue * self;
	self = VALA_CCODE_ENUM_VALUE (object);
	switch (property_id) {
		case VALA_CCODE_ENUM_VALUE_NAME:
		vala_ccode_enum_value_set_name (self, g_value_get_string (value));
		break;
		case VALA_CCODE_ENUM_VALUE_VALUE:
		vala_ccode_enum_value_set_value (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_ccode_enum_value_class_init (ValaCCodeEnumValueClass * klass) {
	vala_ccode_enum_value_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaCCodeEnumValuePrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_ccode_enum_value_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_ccode_enum_value_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_ccode_enum_value_dispose;
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_enum_value_real_write;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ENUM_VALUE_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ENUM_VALUE_VALUE, g_param_spec_object ("value", "value", "value", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void vala_ccode_enum_value_init (ValaCCodeEnumValue * self) {
	self->priv = VALA_CCODE_ENUM_VALUE_GET_PRIVATE (self);
}


static void vala_ccode_enum_value_dispose (GObject * obj) {
	ValaCCodeEnumValue * self;
	self = VALA_CCODE_ENUM_VALUE (obj);
	self->priv->_name = (g_free (self->priv->_name), NULL);
	(self->priv->_value == NULL ? NULL : (self->priv->_value = (g_object_unref (self->priv->_value), NULL)));
	G_OBJECT_CLASS (vala_ccode_enum_value_parent_class)->dispose (obj);
}


GType vala_ccode_enum_value_get_type (void) {
	static GType vala_ccode_enum_value_type_id = 0;
	if (G_UNLIKELY (vala_ccode_enum_value_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeEnumValueClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_enum_value_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeEnumValue), 0, (GInstanceInitFunc) vala_ccode_enum_value_init };
		vala_ccode_enum_value_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeEnumValue", &g_define_type_info, 0);
	}
	return vala_ccode_enum_value_type_id;
}
